@@ -1,16 +1,16 @@
 ##################################################################
 ## spacings
 
-spacing_equal <- function(sp = unit(0.5, "lines")) {
+spacing_equal <- function(sp = unit(0.3, "lines")) {
   if (!is.unit(sp)) sp <- unit(sp, "lines")
-  function(d, condvars = NULL) lapply(d, function(x) rep(sp, x - 1))
+  function(d, condvars = NULL) lapply(d, function(x) if(x > 1) rep(sp, x - 1) else NA)
 }
 class(spacing_equal) <- "grapcon_generator"
 
 spacing_dimequal <- function(sp) {
   if (!is.unit(sp)) sp <- unit(sp, "lines")
   function(d, condvars = NULL)
-    lapply(seq(along = d), function(i) rep(sp[i], d[i] - 1))
+    lapply(seq(along = d), function(i) if(d[i] > 1) rep(sp[i], d[i] - 1) else NA)
 }
 class(spacing_dimequal) <- "grapcon_generator"
 
@@ -18,7 +18,7 @@ spacing_increase <- function(start = unit(0.3, "lines"), rate = 1.5) {
   if (!is.unit(start)) start <- unit(start, "lines")
   function(d, condvars = NULL) {
     sp <- start * rev(cumprod(c(1, rep.int(rate, length(d) - 1))))
-    lapply(seq(along = d), function(i) rep(sp[i], d[i] - 1))
+    spacing_dimequal(sp)(d = d, condvars = condvars)
   }
 }
 class(spacing_increase) <- "grapcon_generator"
@@ -31,7 +31,7 @@ spacing_highlighting <- function(start = unit(0.2, "lines"), rate = 1.5) {
 }
 class(spacing_highlighting) <- "grapcon_generator"
 
-spacing_conditional <- function(sp = unit(0.5, "lines"),
+spacing_conditional <- function(sp = unit(0.3, "lines"),
                                 start = unit(2, "lines"), rate = 1.8) {
   condfun <- spacing_increase(start, rate)
   equalfun <- spacing_equal(sp)
